
version 8           // tell Stata which version program was created in

clear
set more off
set matsize 5000
set memory 800m

// create or overwrite output file gdptemp.smcl in ascii format

capture log close
log using kltozbach.log, replace                       


************************************************************************************************************
//
//		THIS PROGRAM TAKES THE RSS, CRU AND GISS DATA FROM SCHMIDT PLUS THE GISS LAND MASK
//
//		AND COMPUTES AMPLIFICATIONS
//
************************************************************************************************************


//															DATA COMPONENT
//           Clear data then reads data from giss2.csv 
clear
set memory 50m

insheet using giss2.csv						// corrected version of Schmidt's data
	save g440, replace					// taken from http://www.giss.nasa.gov/staff/gschmidt/supp_data_Schmidt09.zip
	clear

insheet using landmask.csv					// supplied to me by Gavin Schmidt
	merge using g440
	save grids, replace


mvdecode _all, mv(-9999)                   // converts CRU and RSS data -9999 to Missing value code

//                                         convert from deg/year to deg/decade
replace cru2v=cru2v*10
replace cru3v=cru3v*10
replace rss=rss*10

replace giss1s=giss1s*10
replace giss2s=giss2s*10
replace giss3s=giss3s*10
replace giss4s=giss4s*10
replace giss5s=giss5s*10
replace gisses=gisses*10
//															DATA COMPONENT
replace giss1t=giss1t*10
replace giss2t=giss2t*10
replace giss3t=giss3t*10
replace giss4t=giss4t*10
replace giss5t=giss5t*10
replace gisset=gisset*10

//					Generate amplification ratios using CRU2v

generate gissrat=gisset/gisses
generate rssrat=rss/cru2v

//					Generate weights by relative gridcell size
generate coslat = cos(lat*3.1415927/180)
egen sgcs = sum(coslat)
generate gcs=coslat/sgcs

sum

// unweighted amplification ratios
sum gissrat rssrat gisset gisses rss cru2v cru3v
by gissocean, sort: sum gissrat rssrat gisset gisses rss cru2v cru3v 

// weighted amplification ratios
sum gissrat rssrat gisset gisses rss cru2v cru3v [w=gcs]			
by gissocean: sum gissrat rssrat gisset gisses rss cru2v cru3v [w=gcs]			



exit

